<?php
/**
 * @link              http://dayes.co/
 * @since             1.0
 * @package           EDD_Yandex_Payment_Gateway
 *
 * @wordpress-plugin
 * Plugin Name:       EDD Yandex Payment Gateway
 * Plugin URI:        http://dayes.co/
 * Description:       EDD Yandex Payment Gateway
 * Version:           1.0
 * Author:            Dayes
 * Author URI:        http://dayes.co/
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       edd-yandex
  */
  
  if ( ! defined( 'WPINC' ) ) {
	die;
}

define('WP_DEBUG', true);

load_plugin_textdomain('edd-yandex', false, dirname(plugin_basename(__FILE__)) . '/languages/');
// registers gateway
function yandex_edd_register_gateway($gateways) {
	$gateways['yandex'] = array('admin_label' => 'Yandex Money', 'checkout_label' => __('Yandex Money', 'edd-yandex'));
	return $gateways;
}
add_filter('edd_payment_gateways', 'yandex_edd_register_gateway');

// removes default CC form
function yandex_edd_sample_gateway_cc_form() {
	return;
}
add_action('edd_yandex_cc_form', 'yandex_edd_sample_gateway_cc_form');

// adds the settings
function yandex_edd_add_settings( $settings ) {

	$aSettings = array(
		array(
			'id' => '_edd_yandex_gateway_settings',
			'name' => '<strong>' . __('Yandex Money Gateway Settings', 'edd-yandex') . '</strong> | by <a href="http://dayes.co/" target="_blank">Dayes</a>',
			'desc' => __('Configure the gateway settings', 'edd-yandex'),
			'type' => 'header'
		),
		array(
			'id' => 'edd_yandex_merchant_id',
			'name' => __('Yandex Money Wallet number', 'edd-yandex'),
			'desc' => __('Enter Wallet number of Yandex Money', 'edd-yandex'),
			'type' => 'text',
			'size' => 'regular'
		),
		
		array(
			'id' => 'edd_yandex_secret',
			'name' => __('Enter the secret word', 'edd-yandex'),
			'desc' => __('Secret word can be found at https://money.yandex.ru/myservices/online.xml', 'edd-yandex'),
			'type' => 'text',
			'size' => 'regular'
		),
		array(
			'id' => 'edd_yandex_return_url',
			'name' => __('Return Url', 'edd-yandex'),
			'desc' => __('Your return url', 'edd-yandex'),
			'type' => 'text',
			'size' => 'regular'
		),
		
		
		array(
			'id' => 'edd_yandex_curs',
			'name' => __('Currency Rate', 'edd-yandex'),
			'desc' => __('Enter the exchange rate against the currency of the sale of goods. If sold in rubles, exchange rate is 1.', 'edd-yandex'),
			'type' => 'text',
			'size' => 'regular'
		),
		
		
		array(
			'id' => 'edd_yandex_order_desc',
			'name' => __('Order description', 'edd-yandex'),
			'desc' => __('Text for order description field', 'edd-yandex'),
			'type' => 'text',
			'size' => 'regular'
		)
	);

	return array_merge($settings, $aSettings);
}
add_filter('edd_settings_gateways', 'yandex_edd_add_settings');

// processes the payment
function yandex_edd_process_payment( $purchase_data ) {

	global $edd_options;

	// check for any stored errors
	$errors = edd_get_errors();

	if(!$errors) {

		$purchase_summary = edd_get_purchase_summary($purchase_data);

		$payment_data = array(
				'price' => $purchase_data['price'],
				'date' => $purchase_data['date'],
				'user_email' => $purchase_data['user_email'],
				'purchase_key' => $purchase_data['purchase_key'],
				'currency' => $edd_options['currency'],
				'downloads' => $purchase_data['downloads'],
				'user_info' => $purchase_data['user_info'],
				'cart_details' => $purchase_data['cart_details'],
				'status' => 'pending'
		);

		// creates a payment with 'pending' status
		$payment = edd_insert_payment( $payment_data );

		$merchant_payment_confirmed = false;

		// if the merchant payment is complete, set a flag
		$merchant_payment_confirmed = true;

		if ( !$payment ) {
		    // Record the error
			edd_record_gateway_error( __( 'Payment Error' ), sprintf( __( 'Payment creation failed before sending buyer to Interkassa. Payment data: %s', 'edd-yandex' ), json_encode( $payment_data ) ), $payment );
            edd_send_back_to_checkout('?payment-mode=' . $purchase_data['post_data']['edd-gateway']);
		} else {
            edd_empty_cart();
            $redirect = add_query_arg(array( 'pay_gateway' => $purchase_data['post_data']['edd-gateway'] ), edd_get_success_page_uri());
	        wp_redirect( apply_filters('edd_success_page_redirect', $redirect, $_POST['edd-gateway'], $query_string) );
	        edd_die();
		} //end statement payment

	} else {
		$fail = true; // errors were detected
	}

	if( $fail !== false ) {
		// if errors are present, send the user back to the purchase page so they can be corrected
		edd_send_back_to_checkout('?payment-mode=' . $purchase_data['post_data']['edd-gateway']);
	}
}
add_action('edd_gateway_yandex', 'yandex_edd_process_payment');

//
function yandex_edd_receipt_after_table( $payment, $edd_receipt_args ) {
        global $edd_options;

        if ( isset($_GET['pay_gateway']) && $_GET['pay_gateway'] == 'yandex' ) {

        if ( $payment->ID && $payment->post_status == 'pending' ) {
            
            
            $action_adr = "https://money.yandex.ru/quickpay/confirm.xml";            
            $args = array(
			'receiver' => $edd_options['edd_yandex_merchant_id'],
			'formcomment' => $edd_options['edd_yandex_order_desc'] .$payment->ID,
			'short-dest' => $edd_options['edd_yandex_order_desc'] .$payment->ID,
			'quickpay-form'  => 'shop',
			'label' => $payment->ID,
			'targets' => 'транзакция '.$payment->ID,				
			'successURL' => $edd_options['edd_yandex_return_url'],			
			'sum' => edd_get_payment_amount( $payment->ID )*$edd_options['edd_yandex_curs'],			
            
            );
            
            $args_array = array();
            foreach ($args as $key => $value) {
                $args_array[] = '<input type="hidden" name="' . $key . '" value="' . $value . '" />';
            }
            $sOutput = '
            <form accept-charset="uth-8" action="' . $action_adr . '" method="POST" name="yandex_form"> 
            <label><input type="radio" name="paymentType" value="PC" checked> '.__('Yandex Money', 'edd-yandex').' </label> <label><input type="radio" name="paymentType" value="AC"> '.__('Bank card', 'edd-yandex').' </label>
            <br/><input type="submit" value="'.__('Pay', 'edd-yandex').'" /> '.
                implode($args_array) .
                '</form>';
            echo $sOutput; 
            

            
        }

        }
}

add_action( 'edd_payment_receipt_after_table', 'yandex_edd_receipt_after_table', 10, 2 );

add_action( 'init', 'yandex_validate_report_back' );
add_action( 'edd_yandex_check', 'yandex_process_notify' );

//
function yandex_validate_report_back() {
		global $edd_options;

		// Regular notify
		if ($_POST['notification_type'])
			do_action( 'edd_yandex_check' );
		} //end statement
		

//
function yandex_process_notify() {

		global $edd_options;		
				
		$secret_key = $edd_options['edd_yandex_secret'];        
        $sha1 = sha1( $_POST['notification_type'] . '&'. $_POST['operation_id']. '&' . $_POST['amount'] . '&643&' . $_POST['datetime'] . '&'. $_POST['sender'] . '&' . $_POST['codepro'] . '&' . $secret_key. '&' . $_POST['label'] );
        $order_id = $_POST['label'];        
        if ($sha1 != $_POST['sha1_hash'] ) {
            edd_insert_payment_note( $order_id, __( 'Payment is not paid', 'edd-yandex') );
            edd_update_payment_status( $order_id, 'pending' );
            exit();
        } 
        edd_insert_payment_note( $order_id, __( 'Payment successfully paid through Yandex Money', 'edd-yandex') );
        edd_update_payment_status( $order_id, 'publish' );        
        exit();
        }


?>